import requests
from typing import Optional


class EconometricAI:
    def __init__(self):
        """Инициализация AI интерпретатора

        Args:
            api_token: токен для доступа к API
        """
        self.API_URL = "https://api.deepinfra.com/v1/openai/chat/completions"
        self.API_TOKEN = 'g4Qd1qksVb7oq4Jwzz7EKYByx63pmFe8'

    def interpret_results(self, stats_data: str) -> str:
        """Интерпретация результатов с помощью AI

        Args:
            stats_data: строка с статистическими данными

        Returns:
            str: интерпретация результатов
        """
        headers = {
            "Authorization": f"Bearer {self.API_TOKEN}",
            "Content-Type": "application/json"
        }

        messages = [
            {"role": "system", "content": '''
Вы - опытный эконометрист, которому поручено провести полный анализ регрессионной модели, построенной в рамках данного задания. Ваша задача - подготовить содержательную аналитическую записку, раскрывающую ключевые статистические и экономические аспекты.
Статистический анализ:

Оценить качество подгонки модели по значениям R-квадрат и скорректированного R-квадрат. Сделать вывод о доле объясненной дисперсии.
Проанализировать значимость F-статистики, чтобы установить, является ли модель значимой в целом.
Изучить t-статистики для оценки значимости отдельных коэффициентов.
Проверить модель на наличие гетероскедастичности и проанализировать распределение остатков.
Сформулировать выводы о статистической надежности и качестве регрессионной модели.

Экономическая интерпретация:

Объяснить экономический смысл полученных коэффициентов регрессии.
Оценить практическую значимость результатов модели для реальной экономической ситуации.
Описать возможные экономические последствия и дать рекомендации по экономической политике.
Выявить ключевые экономические взаимосвязи, которые модель помогает понять.

При формулировке выводов по каждому пункту:

Для построения спецификации модели: Указать характер и силу взаимосвязи между объясняемой и объясняющей переменными.
Для оценивания качества модели: Охарактеризовать качество подгонки, статистическую значимость модели и коэффициентов, точность модели.
Для проверки предпосылок: Указать, выполняются ли предпосылки Гаусса-Маркова.
Для доверительного интервала: Рассчитать ожидаемое изменение эндогенной переменной и доверительный интервал.

В аналитической записке ограничьтесь примерно 500 символами. Сформулируйте конкретные выводы по каждому из пунктов анализа, основываясь на полученных результатах.
            '''},
            {"role": "user", "content": stats_data}
        ]

        data = {
            "model": "Qwen/Qwen2.5-72B-Instruct",
            "messages": messages
        }

        try:
            response = requests.post(self.API_URL, headers=headers, json=data)
            response.raise_for_status()
            return response.json()["choices"][0]["message"]["content"]
        except Exception as e:
            return f"Error: {str(e)}"
